.. _how-to-refer-page:

===========================
 How to Refer to PyMetrology ?
===========================

Up to now, the official url for PyMetrology is https://pymetrology.fabrice-salvaire.fr

*A permanent redirection will be implemented if the domain change in the future.*

On Github, you can use the **pymetrology** `topic <https://github.com/search?q=topic%3Apymetrology&type=Repositories>`_ for repository related to PyMetrology.

A typical `BibTeX <https://en.wikipedia.org/wiki/BibTeX>`_ citation would be, for example:

.. code:: bibtex

    @software{PyMetrology,
      author = {Fabrice Salvaire}, % actual author and maintainer
      title = {PyMetrology},
      url = {https://pymetrology.fabrice-salvaire.fr},
      version = {x.y},
      date = {yyyy-mm-dd}, % set to the release date
    }

    @Misc{PyMetrology,
      author = {Fabrice Salvaire},
      title = {PyMetrology},
      howpublished = {\url{https://pymetrology.fabrice-salvaire.fr}},
      year = {yyyy}
    }
